@@ -36,8 +36,4 @@ class Block(TextElement):
                 pass
 
     def get_sentences(self) -> List[Sentence]:
-        return self.components
-
-    def __str__(self):
-        return self.text
-
+        return self.components
\ No newline at end of file
