@@ -24,19 +24,9 @@ class BertWrapper:
         elif lang is Lang.RO:
             if model_name is None:
                 model_name = "base"
-            if check_updates and check_version(Lang.RO, ["bert", model_name]):
-                download_model(Lang.RO, ["bert", model_name])
-            self.model_dir = os.path.join("resources/ro/bert/", model_name)
-            json_config_file = os.path.join(self.model_dir, "bert_config.json")
-            config = json.load(open(json_config_file, 'r'))
-            do_lower_case = bool(config.get('do_lower_case', 0))
-            do_remove_accents = bool(config.get('do_remove_accents', 1))
-            self.hidden_size = config.get('hidden_size')
-            self.tokenizer = FullTokenizer(vocab_file=os.path.join(self.model_dir, "vocab.vocab"), do_lower_case=do_lower_case)
-            if do_remove_accents == False:
-                self.tokenizer.basic_tokenizer._run_strip_accents = lambda x:x
-            bert_params = bert.params_from_pretrained_ckpt(self.model_dir)
-            self.bert_layer = bert.BertModelLayer.from_params(bert_params, name="bert_layer")
+            model_name = f"readerbench/RoBERT-{model_name}"
+            self.tokenizer = AutoTokenizer.from_pretrained(model_name)
+            self.bert_layer = TFAutoModelWithLMHead.from_pretrained(model_name)
         elif lang is Lang.FR:
             self.tokenizer = FlaubertTokenizer.from_pretrained("jplu/tf-flaubert-base-cased")
             self.bert_layer = TFFlaubertModel.from_pretrained("jplu/tf-flaubert-base-cased")
@@ -53,8 +43,6 @@ class BertWrapper:
     def create_inputs(self) -> List[keras.layers.Layer]:
         input_ids = tf.keras.layers.Input(shape=(self.max_seq_len,), dtype=tf.int32, name="input_ids")
         segment_ids = tf.keras.layers.Input(shape=(self.max_seq_len,), dtype=tf.int32, name="segment_ids")
-        if self.lang is Lang.RO:
-            return [input_ids, segment_ids]
         mask_ids = tf.keras.layers.Input(shape=(self.max_seq_len,), dtype=tf.int32, name="mask_ids")
         return [input_ids, mask_ids, segment_ids]
         
@@ -68,12 +56,7 @@ class BertWrapper:
         return inputs, output
 
     def get_output(self, bert_tensor: tf.Tensor, mode: str = "cls") -> tf.Tensor:
-        if self.lang is Lang.EN:
-            sequence_output = bert_tensor[0]
-        elif self.lang is Lang.RO:
-            sequence_output = bert_tensor
-        elif self.lang is Lang.FR:
-            sequence_output = bert_tensor[0]
+        sequence_output = bert_tensor[0]
         if mode == "cls":
             return tf.keras.layers.Lambda(lambda x: x[:,0,:])(sequence_output)
         elif mode == "pool":
